![Documentation Status](https://readthedocs.org/projects/ontoma/badge/?version=stable) ![Build Status](https://img.shields.io/circleci/build/gh/opentargets/OnToma)

OnToma is a Python module which maps the disease or phenotype terms to [EFO,](https://www.ebi.ac.uk/efo/) the ontology used in the Open Targets platform.

The documentation is available at **https://ontoma.readthedocs.io/.**
